#!/bin/bash
# (c) Copyright 2007-2016 Hewlett Packard Enterprise Development LP.
# Version: A.12.00.50
#

# Sourcing cluster configuration file and utils.sh as it is required
# during online reconfiguration of the package attributes.

. /etc/cmcluster.conf

if [[ -z $SG_UTILS ]]; then
    SG_UTILS=$SGCONF/scripts/mscripts/utils.sh
fi

if [[ -f ${SG_UTILS} ]]; then
   . ${SG_UTILS}
   if (( $? != 0 ))
   then
      echo "ERROR: Unable to source package utility functions file: ${SG_UTILS}"
      exit 1
   fi
else
   echo "ERROR: Unable to find package utility functions file: ${SG_UTILS}"
   exit 1
fi

# This is needed as some of the SG Package attributes are used in SG_UTILS
# script
sg_source_pkg_env $*

#Check the release version of Redhat if OS is RedHat.
#Else check whether the OS is SUSE and determine the destro version.
#Setting the default value for release as -1
release=-1

rpc_service="/usr/lib/systemd/system/rpcbind.service"
statd_service="/usr/lib/systemd/system/rpc-statd.service"
idmap_service="/usr/lib/systemd/system/nfs-idmapd.service"
nfs_service="/usr/lib/systemd/system/nfs-server.service"
mountd_service="/usr/lib/systemd/system/nfs-mountd.service"

if [[ -f /etc/redhat-release ]]; then
   release_num=`cat /etc/redhat-release | cut -d " " -f 7 | cut -d "." -f 1`
   if [[ $release_num -ge 6 ]] ; then
      release=0
   else
      release=1
   fi
else
   IS_SUSE=`cat /proc/version | grep -i "SuSE" | grep -v "grep"`
   if [[ -z "${IS_SUSE}" ]]; then
      echo "ERROR: Unable to find out the SuSE Distribution release information"
      exit 1
   fi
fi


HOST="127.0.0.1"
QUOTA_MON=`echo $QUOTA_MON | tr "[:lower:]" "[:upper:]" | tr -d "[:space:]"`

#Minimum NFS rpc protocol version supported is 2
min_nfsrpc_version=2

# Define portmap, rpc.statd, rpc.rquotad, rpc.mountd, nfsd, lockd, and
# their corresponding program number in pairs.
# Check if package is configured for NFSv4 version of protocol, then
# start only those daemons which are required by NFSv4 protocol.

  if [[ -z ${NFSv4_VIRTUAL_ROOT} ]]; then
     if [[ $release -eq 0 ]] || [[ ! -z "$IS_SUSE" ]] ; then
        HA_SERVER_PROC[0]="rpcbind"
        HA_SERVER[0]="/sbin/rpcbind"
     else
        HA_SERVER_PROC[0]="portmap"
        HA_SERVER[0]="/sbin/portmap"
     fi
     HA_SERVER_PROG[0]="100000"
     HA_SERVER_VER[0]=2


  HA_SERVER_PROC[1]="rpc.mountd"
  HA_SERVER[1]="/usr/sbin/rpc.mountd"
  HA_SERVER_PROG[1]="100005"
  HA_SERVER_VER[1]=3

  HA_SERVER_PROC[2]="nfsd"
  HA_SERVER[2]="/usr/sbin/rpc.nfsd"
  HA_SERVER_PROG[2]="100003"

  #Setting the HA_SERVER_VER for rpc.nfsd based on the availability
  #of the NFS RPC protocol version. This is required because
  #in RHEL7 and SLES12 by default version 2 is not enabled.
  if rpcinfo -u $HOST ${HA_SERVER_PROG[2]} $min_nfsrpc_version > /dev/null 2>&1
  then
    HA_SERVER_VER[2]=2
  else
    HA_SERVER_VER[2]=3
  fi

  #If it is RH5 system and not sles, nor RH6 and above.
  if [[ -z "${IS_SUSE}" ]] && [[ $release -eq 1 ]]; then
      HA_SERVER_PROC[3]="lockd"
      HA_SERVER[3]="/sbin/rpc.lockd"
      HA_SERVER_PROG[3]="100021"
      HA_SERVER_VER[3]=3

      HA_SERVER_PROC[4]="rpc.statd"
      HA_SERVER[4]="/sbin/rpc.statd"
      HA_SERVER_PROG[4]="100024"
      HA_SERVER_VER[4]=1


      if [[ $QUOTA_MON == "YES" ]]; then
        HA_SERVER_PROC[5]="rpc.rquotad"
        HA_SERVER[5]="/usr/sbin/rpc.rquotad"
        HA_SERVER_PROG[5]="100011"
        HA_SERVER_VER[5]=2
      fi
  else
      #If it is RH6 and above system or SLES 11 and above system
      HA_SERVER_PROC[3]="rpc.statd"
      HA_SERVER[3]="/sbin/rpc.statd"
      HA_SERVER_PROG[3]="100024"
      HA_SERVER_VER[3]=1

      if [[ $QUOTA_MON == "YES" ]]; then
         HA_SERVER_PROC[4]="rpc.rquotad"
         HA_SERVER[4]="/usr/sbin/rpc.rquotad"
         HA_SERVER_PROG[4]="100011"
         HA_SERVER_VER[4]=2
      fi
  fi

else    # NFSv4 is being used so make an array of mountd and nfsd.

  HA_SERVER_PROC[0]="rpc.mountd"
  HA_SERVER[0]="/usr/sbin/rpc.mountd"
  HA_SERVER_PROG[0]="100005"
  HA_SERVER_VER[0]=3

  HA_SERVER_PROC[1]="nfsd"
  HA_SERVER[1]="/usr/sbin/rpc.nfsd"
  HA_SERVER_PROG[1]="100003"
  HA_SERVER_VER[1]=4

  if [[ ! -z "${IS_SUSE}" ]]; then
     HA_SERVER_PROC[2]="rpcbind"
     HA_SERVER[2]="/sbin/rpcbind"
     HA_SERVER_PROG[2]="100000"
     HA_SERVER_VER[2]=2
  fi

fi

